local _G = getfenv(0);

local cfg = TipTac_Config;

local TTO_Sliders = {
	{ var = "updateFreq", label = "Tip Update Frequency", min = 0, max = 5, step = 0.05 },
	{ var = "tipScale", label = "TipTac Scale", min = 0.4, max = 2, step = 0.05 },
	{ var = "gttScale", label = "GameTooltip Scale", min = 0.4, max = 2, step = 0.05 },
	{ var = "preFadeTime", label = "Pre Fade Time", min = 0, max = 5, step = 0.05 },
	{ var = "fadeTime", label = "Fade Out Time", min = 0, max = 5, step = 0.05 },
	{ var = "mouseOffsetX", label = "Mouse Anchor X Offset", min = -40, max = 40, step = 1 },
	{ var = "mouseOffsetY", label = "Mouse Anchor Y Offset", min = -40, max = 40, step = 1 },
};

local TTO_Checks = {
	{ var = "showTip", label = "Show TipTac Unit Tips", tip = "If you disable this option, you will only really take advantage of the anchor option in TipTac" },
	{ var = "showTargetedBy", label = "Show Who Targets the Unit", tip = "When in a raid or party, it will show who from your group is targeting the unit" },
	{ var = "pvpName", label = "Use PvP Name If Available", tip = "Show PvP title for players if available" },
};

--------------------------------------------------------------------------------------------------------
--                                           Frame Scripts                                            --
--------------------------------------------------------------------------------------------------------
function TipTacOptions_OnLoad()
	TipTacOptionsVers:SetText("|cffffff80"..TipTacAnchor.modVers);
	if (TipTacAnchor) then
		TipTacOptionsAnchor:Show();
	end
	-- Slider Frames Init
	for index, table in ipairs(TTO_Sliders) do
		local slider = ("TipTacOptionsSlider"..index.."Slider");

		_G[slider]:SetMinMaxValues(table.min,table.max);
		_G[slider]:SetValueStep(table.step);
		_G[slider]:SetValue(cfg[table.var]);
		_G["TipTacOptionsSlider"..index.."Edit"]:SetNumber(cfg[table.var]);

		_G[slider.."Text"]:SetText(table.label);
		_G[slider.."Low"]:SetText(table.min);
		_G[slider.."High"]:SetText(table.max);
	end
	-- Check Boxes Init
	for index, table in ipairs(TTO_Checks) do
		_G["TipTacOptionsCheck"..index.."Text"]:SetText(table.label);
		_G["TipTacOptionsCheck"..index].tooltipText = table.tip;
		_G["TipTacOptionsCheck"..index]:SetChecked(cfg[table.var]);
	end
end

--------------------------------------------------------------------------------------------------------
--                                            Slider Frame                                            --
--------------------------------------------------------------------------------------------------------

-- Slider Value Changed
function TipTacOptions_Slider_OnValueChanged()
	-- Tooltip
	if (GameTooltip:IsOwned(this)) then
		GameTooltip:SetText(format("%.2f",this:GetValue()));
	end
	-- Change Edit
	_G[this:GetParent():GetName().."Edit"]:SetNumber(this:GetValue());
	-- Save & Apply
	cfg[TTO_Sliders[this:GetParent():GetID()].var] = this:GetValue();
	TipTac_ApplySettings();
end

-- EditBox Enter Pressed
function TipTacOptions_SliderEdit_OnEnterPressed()
	_G[this:GetParent():GetName().."Slider"]:SetValue(this:GetNumber());
end

-- OnMouseWheel
function TipTacOptions_Slider_OnMouseWheel()
	this:SetValue(this:GetValue() + TTO_Sliders[this:GetParent():GetID()].step * arg1);
end

--------------------------------------------------------------------------------------------------------
--                                           Check Buttons                                            --
--------------------------------------------------------------------------------------------------------
function TipTacOptions_CheckBox_OnClick()
	cfg[TTO_Checks[this:GetID()].var] = (this:GetChecked() == 1);
end

--------------------------------------------------------------------------------------------------------
--                                                Misc                                                --
--------------------------------------------------------------------------------------------------------
function TipTacOptions_Anchor()
	if (TipTacAnchor:IsVisible()) then
		TipTacAnchor:Hide();
	else
		TipTacAnchor:Show();
	end
end